@@ -21,17 +21,13 @@ export MACOSX_DEPLOYMENT_TARGET=12
 
 # ``readlink -f`` is not our friend on OS X. This relies on **some**
 # ``python`` being installed.
-SCRIPT_FI=$(python -c "import os; print(os.path.realpath('${0}'))")
+SCRIPT_FI=$(python3 -c "import os; print(os.path.realpath('${0}'))")
 OSX_DIR=$(dirname ${SCRIPT_FI})
 SCRIPTS_DIR=$(dirname ${OSX_DIR})
 export REPO_ROOT=$(dirname ${SCRIPTS_DIR})
 
-# install required packages for pyenv
-# https://github.com/pyenv/pyenv/wiki#suggested-build-environment
-brew install openssl readline sqlite3 xz zlib tcl-tk
-
 # Build and install `libcrc32c`
-export PY_BIN="${PY_BIN:-python3}"
+export PY_BIN="python3"
 export CRC32C_INSTALL_PREFIX="${REPO_ROOT}/usr"
 
 cd ${REPO_ROOT}
@@ -42,7 +38,11 @@ git submodule update --init --recursive
 
 ${OSX_DIR}/build_c_lib.sh
 
-SUPPORTED_PYTHON_VERSIONS=("3.9" "3.10" "3.11" "3.12")
+# reinstall pyenv
+rm -rf /Users/kbuilder/.pyenv
+git clone https://github.com/pyenv/pyenv.git /Users/kbuilder/.pyenv
+
+SUPPORTED_PYTHON_VERSIONS=("3.9" "3.10" "3.11" "3.12" "3.13" "3.14")
 
 for PYTHON_VERSION in ${SUPPORTED_PYTHON_VERSIONS[@]}; do
     echo "Build wheel for Python ${PYTHON_VERSION}"
