@@ -43,8 +43,6 @@ fi
 mkdir -p ${CRC32C_INSTALL_PREFIX}
 mkdir -p ${CRC32C_INSTALL_PREFIX}/lib
 
-# Make sure we have an updated `pip`.
-${PY_BIN} -m pip install --upgrade pip --user
 # Create a virtualenv where we can install `cmake`.
 VENV=${REPO_ROOT}/venv_build_libcrc32c
 ${PY_BIN} -m venv ${VENV}
@@ -67,6 +65,7 @@ ${VENV}/bin/cmake \
     -DBUILD_SHARED_LIBS=yes \
     -DCMAKE_INSTALL_PREFIX:PATH=${CRC32C_INSTALL_PREFIX} \
     -DCMAKE_INSTALL_NAME_DIR:PATH=${CRC32C_INSTALL_PREFIX}/lib \
+    -DCMAKE_POLICY_VERSION_MINIMUM=3.12 \
     ..
 
 # Install `libcrc32c` into CRC32C_INSTALL_PREFIX.
