@@ -51,6 +51,14 @@ install_python_pyenv() {
 }
 install_python_pyenv ${PY_BIN}
 
+
+# ``readlink -f`` is not our friend on OS X. This relies on **some**
+# ``python`` being installed.
+SCRIPT_FI=$(python3 -c "import os; print(os.path.realpath('${0}'))")
+OSX_DIR=$(dirname ${SCRIPT_FI})
+SCRIPTS_DIR=$(dirname ${OSX_DIR})
+export REPO_ROOT=$(dirname ${SCRIPTS_DIR})
+
 # Create a virtualenv where we can install Python build dependencies.
 VENV=${REPO_ROOT}/venv${PY_BIN}
 "python${PY_BIN}" -m venv ${VENV}
@@ -82,6 +90,15 @@ if [[ "${PUBLISH_WHEELS}" == "true" ]]; then
     . /${OSX_DIR}/publish_python_wheel.sh
 fi
 
+# test wheel
+${VENV}/bin/pip install \
+  --no-index --find-links=${REPO_ROOT}/wheels google-crc32c --force-reinstall
+${VENV}/bin/pip install pytest
+${VENV}/bin/py.test ${REPO_ROOT}/tests
+${VENV}/bin/python ${REPO_ROOT}/scripts/check_crc32c_extension.py
+
+ls ${REPO_ROOT}/wheels/
+
 # Clean up.
 rm -fr ${DIST_WHEELS}
 rm -fr ${VENV}
